@@ -28,7 +28,7 @@ char random_char(void) {
   return rand();
 }
 
-void randomize_buffer(char *buffer, int length) {
+void randomize_buffer(unsigned char *buffer, int length) {
   int i;
 
   if (urand_file != -1) {
