@@ -47,7 +47,13 @@ int rename_unlink(const char *path) {
 
   sync();
 
-  stat(new_name, &statbuf);
+  if (lstat(new_name, &statbuf) == -1) {
+    /* Bad mojo, we just renamed to new_name and now the path is invalid.
+       Die ungracefully and exit before anything worse happens. */
+    perror("Fatal error in rename_unlink()");
+    exit(EXIT_FAILURE);
+  }
+  
 
   if (S_ISDIR(statbuf.st_mode))
     return rmdir(new_name);
