@@ -18,4 +18,4 @@ int tree_walker(char ** trees);
 int sunlink(const char * path, const int simple);
 void init_random(const unsigned int seed);
 char random_char(void);
-void randomize_buffer(char *buffer, int length);
+void randomize_buffer(unsigned char *buffer, int length);
