@@ -28,12 +28,12 @@
 #include "srm.h"
 
 static int file;
-static int file_size;
+static off_t file_size;
 static unsigned char *buffer;
-static int buffsize;
+static unsigned int buffsize;
 
 static void overwrite() {
-  int i = 0;
+  unsigned int i = 0;
 
   lseek(file, 0, SEEK_SET);
   while (i < file_size - buffsize)
