@@ -15,6 +15,19 @@
 
 #include "srm.h"
 
+#ifndef FTS_D
+#define FTS_D      0
+#define FTS_DC     1
+#define FTS_DNR    2
+#define FTS_DOT    3
+#define FTS_DP     4
+#define FTS_ERR    5
+#define FTS_F      6
+#define FTS_SL     7
+#define FTS_SLNONE 8
+#define FTS_NS     9 
+#endif /* ndef FTS_D */
+
 int prompt_user(const char *string) {
   char inbuf[8];
 
@@ -38,55 +51,46 @@ int check_perms(const char *path) {
   return 1;
 }
 
-int prompt_file(const char *path) {
+int prompt_file(const char *path, int fts_flag) {
   int fd, return_value = 1;
   size_t bufsize = strlen(path) + 80;
   char *buf;
 
+  if ( (buf = (char *)malloc(bufsize)) == NULL ) {
+    errorp("Out of memory at line %d in prompt_file()", __LINE__);
+    return 0;
+  }
+
   if (options & OPT_F) {
     if (options & OPT_V)
       printf("removing %s\n", path);
     return check_perms(path);
   }
 
-  if ( (buf = (char *)malloc(bufsize)) == NULL ) {
-    errorp("Out of memory at line %d in prompt_file()", __LINE__);
-    return 0;
-  }
-
-  if ( ((fd = open(path, O_WRONLY)) == -1) && (errno == EACCES) ) {
-    snprintf(buf, bufsize, "Remove write protected file %s? ", path);
-    if ( (return_value = prompt_user(buf)) == 1 ) 
-      return_value = check_perms(path);
-  } else {
-    if (options & OPT_I) {
-      snprintf(buf, bufsize, "Remove %s? ", path);
-      return_value = prompt_user(buf);
+  if ( (fts_flag != FTS_SL) && ((fd = open(path, O_WRONLY)) == -1) &&
+       (errno == EACCES) )
+    {
+      /* Not a symlink, not writable */
+      snprintf(buf, bufsize, "Remove write protected file %s? ", path);
+      if ( (return_value = prompt_user(buf)) == 1 ) 
+	return_value = check_perms(path);
+    } else {
+      /* Writable file or symlink */
+      if (options & OPT_I) {
+	snprintf(buf, bufsize, "Remove %s? ", path);
+	return_value = prompt_user(buf);
+      }
     }
-  }
 
-  if ((options & OPT_V) && return_value)
+  if ((options & OPT_V) && return_value) 
     printf("removing %s\n", path);
 
   free(buf);
-  close(fd); /* close if open succeded, or silently fail */
+  close(fd); /* close if open succeeded, or silently fail */
 
   return return_value;
 }
 
-#ifndef FTS_D
-#define FTS_D      0
-#define FTS_DC     1
-#define FTS_DNR    2
-#define FTS_DOT    3
-#define FTS_DP     4
-#define FTS_ERR    5
-#define FTS_F      6
-#define FTS_SL     7
-#define FTS_SLNONE 8
-#define FTS_NS     9 
-#endif /* ndef FTS_D */
-
 int process_file(char *path, int flag) {
   while (path[strlen(path) - 1] == '/') 
     path[strlen(path)- 1] = '\0';
@@ -97,12 +101,12 @@ int process_file(char *path, int flag) {
     error("cyclic directory entry %s", path);
     break;
   case FTS_DNR:
-    error("%s: %s: permission denied", path);
+    error("%s: permission denied", path);
     break;
   case FTS_DOT: break;
   case FTS_DP:
     if (options & OPT_R) {
-      if ( prompt_file(path) && (rename_unlink(path) == -1) )
+      if ( prompt_file(path, flag) && (rename_unlink(path) == -1) )
 	errorp("unable to remove %s", path);
     } else {
       error("%s is a directory", path);
@@ -114,7 +118,7 @@ int process_file(char *path, int flag) {
   case FTS_F:
   case FTS_SL:
   case FTS_SLNONE:
-    if ( prompt_file(path) && (sunlink(path, options & OPT_S) == -1) ) {
+    if ( prompt_file(path, flag) && (sunlink(path, options & OPT_S) == -1) ) {
       if (errno == EMLINK) 
 	error("%s has multiple links, this one has been removed but not "
 	      "overwritten", path);
